# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingForcedExpiratoryVolume1ChangedEventType(str, enum.Enum):
    DAILY_DATA_FORCED_EXPIRATORY_VOLUME_1_CREATED = "daily.data.forced_expiratory_volume_1.created"
    DAILY_DATA_FORCED_EXPIRATORY_VOLUME_1_UPDATED = "daily.data.forced_expiratory_volume_1.updated"

    def visit(
        self,
        daily_data_forced_expiratory_volume_1_created: typing.Callable[[], T_Result],
        daily_data_forced_expiratory_volume_1_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingForcedExpiratoryVolume1ChangedEventType.DAILY_DATA_FORCED_EXPIRATORY_VOLUME_1_CREATED:
            return daily_data_forced_expiratory_volume_1_created()
        if self is ClientFacingForcedExpiratoryVolume1ChangedEventType.DAILY_DATA_FORCED_EXPIRATORY_VOLUME_1_UPDATED:
            return daily_data_forced_expiratory_volume_1_updated()
