# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingHandwashingChangedEventType(str, enum.Enum):
    DAILY_DATA_HANDWASHING_CREATED = "daily.data.handwashing.created"
    DAILY_DATA_HANDWASHING_UPDATED = "daily.data.handwashing.updated"

    def visit(
        self,
        daily_data_handwashing_created: typing.Callable[[], T_Result],
        daily_data_handwashing_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingHandwashingChangedEventType.DAILY_DATA_HANDWASHING_CREATED:
            return daily_data_handwashing_created()
        if self is ClientFacingHandwashingChangedEventType.DAILY_DATA_HANDWASHING_UPDATED:
            return daily_data_handwashing_updated()
