# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestsGetPaginatedRequestOrderKey(str, enum.Enum):
    PRICE = "price"
    CREATED_AT = "created_at"
    UPDATED_AT = "updated_at"

    def visit(
        self,
        price: typing.Callable[[], T_Result],
        created_at: typing.Callable[[], T_Result],
        updated_at: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LabTestsGetPaginatedRequestOrderKey.PRICE:
            return price()
        if self is LabTestsGetPaginatedRequestOrderKey.CREATED_AT:
            return created_at()
        if self is LabTestsGetPaginatedRequestOrderKey.UPDATED_AT:
            return updated_at()
