# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .source_auth_type import SourceAuthType
from .source_type import SourceType
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class Source(UniversalBaseModel):
    name: str
    slug: str
    description: str
    logo: str
    group: typing.Optional[str] = None
    oauth_url: typing.Optional[str] = None
    auth_type: typing.Optional[SourceAuthType] = None
    source_type: typing.Optional[SourceType] = None
    is_active: typing.Optional[bool] = None
    backfill_num_days: typing.Optional[int] = None
    id: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
