# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .client_facing_note_changed_event_type import ClientFacingNoteChangedEventType
from .grouped_note import GroupedNote
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class ClientFacingNoteChanged(UniversalBaseModel):
    event_type: ClientFacingNoteChangedEventType
    user_id: str
    client_user_id: str
    team_id: str
    data: GroupedNote

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
