# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingDaylightExposureChangedEventType(str, enum.Enum):
    DAILY_DATA_DAYLIGHT_EXPOSURE_CREATED = "daily.data.daylight_exposure.created"
    DAILY_DATA_DAYLIGHT_EXPOSURE_UPDATED = "daily.data.daylight_exposure.updated"

    def visit(
        self,
        daily_data_daylight_exposure_created: typing.Callable[[], T_Result],
        daily_data_daylight_exposure_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingDaylightExposureChangedEventType.DAILY_DATA_DAYLIGHT_EXPOSURE_CREATED:
            return daily_data_daylight_exposure_created()
        if self is ClientFacingDaylightExposureChangedEventType.DAILY_DATA_DAYLIGHT_EXPOSURE_UPDATED:
            return daily_data_daylight_exposure_updated()
