# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingSleepBreathingDisturbanceSampleType(str, enum.Enum):
    ELEVATED = "elevated"
    NOT_ELEVATED = "not_elevated"

    def visit(self, elevated: typing.Callable[[], T_Result], not_elevated: typing.Callable[[], T_Result]) -> T_Result:
        if self is ClientFacingSleepBreathingDisturbanceSampleType.ELEVATED:
            return elevated()
        if self is ClientFacingSleepBreathingDisturbanceSampleType.NOT_ELEVATED:
            return not_elevated()
