# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingOrderChangedEventType(str, enum.Enum):
    LABTEST_ORDER_CREATED = "labtest.order.created"
    LABTEST_ORDER_UPDATED = "labtest.order.updated"

    def visit(
        self, labtest_order_created: typing.Callable[[], T_Result], labtest_order_updated: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is ClientFacingOrderChangedEventType.LABTEST_ORDER_CREATED:
            return labtest_order_created()
        if self is ClientFacingOrderChangedEventType.LABTEST_ORDER_UPDATED:
            return labtest_order_updated()
